Assignments
===========

Instructors can create assignments. Normally, the table of contents for the book will contain a link to an assignments page. The contents of that page are generated automatically by assembling assignments through the instructor interface.

If you choose to assign points to activities that are part of an assignment, there is also a grading interface. Some activities can be auto-graded; others may require manual grading.